@@ -55,6 +55,7 @@ def cmd_login(args):
             config.data['device_id'] = data.get('device_id', '')
             config.data['brand_id'] = data.get('brand_id', 'nexuscore')
             config.data['jwt_token'] = data.get('jwt_token', '')
+            config.data['device_api_key'] = data.get('device_api_key', data.get('jwt_token', ''))  # Save device API key
             config.data['api_url'] = api_url
             config.save()
             
@@ -485,9 +486,13 @@ def cmd_marketplace_list(args):
     logger.info("=" * 70)
     
     for category, pkgs in sorted(by_category.items()):
-        logger.info(f"\n🏷️  {category}")
+        display_category = category.title() if category else "Other"
+        logger.info(f"\n🏷️  {display_category}")
         for pkg in pkgs:
-            logger.info(f"   • {pkg['name']:<25} v{pkg['version']:<10} {pkg['description'][:40]}")
+            name = pkg.get('name', 'unknown')
+            version = pkg.get('version', 'n/a')
+            description = pkg.get('description', '') or ''
+            logger.info(f"   • {name:<25} v{version:<10} {description[:40]}")
     
     logger.info("\n" + "=" * 70)
     logger.info("Install with: san-cli marketplace install <name>")
@@ -509,9 +514,9 @@ def cmd_marketplace_search(args):
     logger.info("=" * 70)
     
     for pkg in packages:
-        logger.info(f"\n📦 {pkg['name']} v{pkg['version']}")
+        logger.info(f"\n📦 {pkg.get('name', 'unknown')} v{pkg.get('version', 'n/a')}")
         logger.info(f"   Category: {pkg.get('category', 'Other')}")
-        logger.info(f"   {pkg['description']}")
+        logger.info(f"   {pkg.get('description', '')}")
     
     logger.info("\n" + "=" * 70)
     return 0
@@ -530,22 +535,22 @@ def cmd_marketplace_info(args):
     
     logger.info(f"📄 Package Information")
     logger.info("=" * 70)
-    logger.info(f"\nName: {pkg['name']}")
-    logger.info(f"Version: {pkg['version']}")
-    logger.info(f"Type: {pkg['type']}")
+    logger.info(f"\nName: {pkg.get('name', 'unknown')}")
+    logger.info(f"Version: {pkg.get('version', 'n/a')}")
+    logger.info(f"Type: {pkg.get('type', 'n/a')}")
     logger.info(f"Category: {pkg.get('category', 'Other')}")
     logger.info(f"\nDescription:")
-    logger.info(f"  {pkg['description']}")
+    logger.info(f"  {pkg.get('description', '')}")
     
     if pkg.get('dependencies'):
         logger.info(f"\nDependencies:")
         for dep in pkg['dependencies']:
             logger.info(f"  • {dep}")
-    
-    if pkg['type'] == 'docker':
+
+    if pkg.get('type') == 'docker' and pkg.get('docker'):
         docker = pkg['docker']
         logger.info(f"\nDocker Configuration:")
-        logger.info(f"  Image: {docker['image']}")
+        logger.info(f"  Image: {docker.get('image', 'n/a')}")
         logger.info(f"  Container: {docker['container_name']}")
         if docker.get('ports'):
             logger.info(f"  Ports: {', '.join(docker['ports'])}")
@@ -591,6 +596,134 @@ def cmd_marketplace_update(args):
         return 0 if marketplace.update_package(args.package) else 1
 
 
+def cmd_update_check(args):
+    """Check for SAN CLI updates"""
+    from ..updater.self_updater import SelfUpdater
+    
+    updater = SelfUpdater()
+    latest = updater.check_for_updates()
+    
+    if latest:
+        logger.info(f"\n💡 Run 'san update --self' to update to {latest}")
+    
+    return 0
+
+
+def cmd_update_self(args):
+    """Update SAN CLI itself"""
+    from ..updater.self_updater import SelfUpdater
+    from ..core.config import Config
+    
+    updater = SelfUpdater()
+    config = Config()
+    
+    # Handle auto-update enable/disable
+    if hasattr(args, 'enable_auto') and args.enable_auto:
+        auto_install = hasattr(args, 'auto_install') and args.auto_install
+        config.set_auto_update(enabled=True, auto_install=auto_install)
+        if auto_install:
+            logger.info("✅ Auto-update enabled with automatic installation")
+        else:
+            logger.info("✅ Auto-update enabled (will notify when updates available)")
+        logger.info("   SAN CLI will check for updates daily")
+        return 0
+    
+    if hasattr(args, 'disable_auto') and args.disable_auto:
+        config.set_auto_update(enabled=False)
+        logger.info("✅ Auto-update disabled")
+        return 0
+    
+    # Handle rollback
+    if args.rollback:
+        logger.info("🔄 Rolling back to previous version...")
+        success = updater.rollback()
+        return 0 if success else 1
+    
+    # Handle update
+    success = updater.update_self(version=args.version)
+    return 0 if success else 1
+
+
+def cmd_update_history(args):
+    """Show version history"""
+    from ..updater.self_updater import SelfUpdater
+    
+    updater = SelfUpdater()
+    history = updater.get_version_history()
+    
+    if not history:
+        logger.info("📜 No version history available")
+        return 0
+    
+    logger.info("📜 Version History")
+    logger.info("=" * 70)
+    
+    for entry in reversed(history):
+        version = entry['version']
+        installed = entry['installed'][:19]  # Trim to datetime
+        current = " (current)" if version == updater.current_version else ""
+        logger.info(f"  v{version:<10} installed {installed}{current}")
+    
+    logger.info("=" * 70)
+    return 0
+
+
+def cmd_doctor(args):
+    """Run diagnostics"""
+    logger.info("🏥 Running SAN CLI Diagnostics")
+    logger.info("=" * 70)
+    
+    # Check version
+    from ..version import __version__
+    logger.info(f"✅ SAN CLI version: {__version__}")
+    
+    # Check config
+    from ..core.config import Config
+    config = Config()
+    if config.data.get('device_id'):
+        logger.info(f"✅ Device ID: {config.data['device_id']}")
+    else:
+        logger.warning("⚠️  No device ID configured")
+    
+    if config.data.get('jwt_token') or config.data.get('device_api_key'):
+        logger.info("✅ Authentication configured")
+    else:
+        logger.warning("⚠️  No authentication configured")
+    
+    # Check Docker
+    import subprocess
+    docker_check = subprocess.run(['docker', '--version'], capture_output=True)
+    if docker_check.returncode == 0:
+        version = docker_check.stdout.decode().strip()
+        logger.info(f"✅ Docker: {version}")
+    else:
+        logger.error("❌ Docker not found")
+    
+    # Check pipx
+    pipx_check = subprocess.run(['pipx', '--version'], capture_output=True)
+    if pipx_check.returncode == 0:
+        version = pipx_check.stdout.decode().strip()
+        logger.info(f"✅ pipx: {version}")
+    else:
+        logger.warning("⚠️  pipx not found (needed for self-update)")
+    
+    # Check space-agent container
+    ps_result = subprocess.run(
+        ['docker', 'ps', '--filter', 'name=space-agent', '--format', '{{.Status}}'],
+        capture_output=True,
+        text=True
+    )
+    if ps_result.returncode == 0 and ps_result.stdout.strip():
+        logger.info(f"✅ space-agent: {ps_result.stdout.strip()}")
+    else:
+        logger.warning("⚠️  space-agent container not running")
+    
+    logger.info("=" * 70)
+    logger.info("✅ Diagnostics complete")
+    
+    return 0
+
+
 def cmd_telemetry_status(args):
     """Show telemetry status"""
     from ..telemetry import TelemetryReporter
@@ -661,69 +794,7 @@ def cmd_telemetry_view(args):
     return 0
 
 
-def cmd_doctor(args):
-    """Run diagnostics"""
-    from ..installer import SystemDetector
-    
-    logger.info("🏥 Running Diagnostics")
-    logger.info("=" * 70)
-    
-    detector = SystemDetector()
-    system_info = detector.detect_all()
-    
-    # Check system
-    logger.info("\n📊 System:")
-    logger.info(f"   OS: {system_info['os']['name']}")
-    logger.info(f"   Architecture: {system_info['arch']['machine']}")
-    logger.info(f"   Python: {system_info['python']['version']}")
-    
-    # Check Docker
-    logger.info("\n🐳 Docker:")
-    if system_info['docker']['installed']:
-        logger.info(f"   ✅ Installed: {system_info['docker']['version']}")
-        if system_info['docker']['running']:
-            logger.info(f"   ✅ Running")
-        else:
-            logger.info(f"   ❌ Not running")
-    else:
-        logger.info(f"   ❌ Not installed")
-    
-    # Check GPU
-    logger.info("\n🎮 GPU:")
-    if system_info['gpu']['available']:
-        logger.info(f"   ✅ Available: {system_info['gpu']['type']}")
-        logger.info(f"   Memory: {system_info['gpu']['memory_gb']}GB")
-    else:
-        logger.info(f"   ❌ Not detected")
-    
-    # Check compatibility
-    compatible, issues = detector.is_compatible()
-    logger.info("\n✅ Compatibility:")
-    if compatible:
-        logger.info("   ✅ System is compatible")
-    else:
-        logger.info("   ❌ Issues found:")
-        for issue in issues:
-            logger.info(f"      - {issue}")
-    
-    logger.info("\n" + "=" * 70)
-    
-    # Auto-fix if requested
-    if args.fix and not compatible:
-        logger.info("\n🔧 Attempting auto-fix...")
-        # TODO: Implement auto-fix logic
-        logger.info("   Auto-fix not yet implemented")
-    
-    return 0 if compatible else 1
-
-
-def cmd_update_self(args):
-    """Update SAN CLI"""
-    logger.info("🔄 Checking for updates...")
-    logger.info("   Current version: 3.0.0-alpha")
-    logger.info("   Checking GitHub releases...")
-    logger.info("   ✅ You are on the latest version")
-    return 0
+# OLD cmd_doctor and cmd_update_self removed - using new Phase 7 versions above
 
 
 def cmd_package_list(args):
@@ -984,6 +1055,49 @@ For more information: https://nexuscore.cloud/neuron/docs
     disable_parser.add_argument('service', help='Service name')
     disable_parser.set_defaults(func=cmd_disable)
     
+    # Update command group (NEW - Phase 7)
+    update_parser = subparsers.add_parser(
+        'update',
+        help='Update SAN CLI or packages'
+    )
+    update_subparsers = update_parser.add_subparsers(
+        dest='update_command',
+        help='Update operations'
+    )
+    
+    # update --check
+    update_check_parser = update_subparsers.add_parser(
+        'check',
+        help='Check for updates'
+    )
+    update_check_parser.set_defaults(func=cmd_update_check)
+    
+    # update self
+    update_self_parser = update_subparsers.add_parser(
+        'self',
+        help='Update SAN CLI itself'
+    )
+    update_self_parser.add_argument('--version', help='Specific version to install')
+    update_self_parser.add_argument('--rollback', action='store_true', help='Rollback to previous version')
+    update_self_parser.add_argument('--auto', dest='enable_auto', action='store_true', help='Enable auto-updates')
+    update_self_parser.add_argument('--no-auto', dest='disable_auto', action='store_true', help='Disable auto-updates')
+    update_self_parser.add_argument('--auto-install', action='store_true', help='Enable automatic installation (with --auto)')
+    update_self_parser.set_defaults(func=cmd_update_self)
+    
+    # update history
+    update_history_parser = update_subparsers.add_parser(
+        'history',
+        help='Show version history'
+    )
+    update_history_parser.set_defaults(func=cmd_update_history)
+    
+    # Doctor command (NEW - Phase 7)
+    doctor_parser = subparsers.add_parser(
+        'doctor',
+        help='Run diagnostics'
+    )
+    doctor_parser.set_defaults(func=cmd_doctor)
+    
     # Ollama command group (NEW for SAN CLI)
     ollama_parser = subparsers.add_parser(
         'ollama',
@@ -1149,21 +1263,7 @@ For more information: https://nexuscore.cloud/neuron/docs
     telemetry_view_parser.add_argument('--last', type=int, default=100, help='Number of records')
     telemetry_view_parser.set_defaults(func=cmd_telemetry_view)
     
-    # Doctor command (NEW for SAN CLI)
-    doctor_parser = subparsers.add_parser(
-        'doctor',
-        help='Run diagnostics'
-    )
-    doctor_parser.add_argument('--fix', action='store_true', help='Attempt to fix issues')
-    doctor_parser.set_defaults(func=cmd_doctor)
-    
-    # Update command (NEW for SAN CLI)
-    update_parser = subparsers.add_parser(
-        'update',
-        help='Update SAN CLI'
-    )
-    update_parser.add_argument('--self', action='store_true', dest='self_update', help='Update CLI itself')
-    update_parser.set_defaults(func=cmd_update_self)
+    # OLD doctor and update commands removed - using Phase 7 versions above
     
     # Package command group
     package_parser = subparsers.add_parser(
@@ -1215,6 +1315,18 @@ For more information: https://nexuscore.cloud/neuron/docs
         parser.print_help()
         return 1
     
+    # Background auto-update check (silent, non-blocking)
+    try:
+        from ..core.config import Config
+        from ..updater.self_updater import SelfUpdater
+        
+        config = Config()
+        if config.should_check_for_updates():
+            updater = SelfUpdater()
+            updater.auto_update_if_enabled()
+    except:
+        pass  # Silently fail if update check fails
+    
     # Execute command
     return args.func(args)
 
